import dotenv from "dotenv";
dotenv.config();

import path from "path";
import express from "express";
import engine from "ejs-mate";

import "@bot/bot";
import prisma from "@server/prisma";
import homeRouter from "@server/routers/home.router";
import guildRouter from "@server/routers/guild.router";
import { attachGuilds } from "@server/middleware/attachGuilds";
import { guildTabHelper } from "@server/middleware/guildTabHelper";

const app = express();

app.engine("ejs", engine);
app.set("view engine", "ejs");
app.set("views", path.resolve(__dirname, "client/views"));
app.use(express.urlencoded({ extended: true }));
app.use(express.json());

app.use("/public", express.static(path.resolve(__dirname, "client/public")));

app.use("/guild", attachGuilds, guildTabHelper, guildRouter);
app.use("/", attachGuilds, homeRouter);

const HOST = process.env.HOST || "localhost";
const PORT = process.env.PORT || 3000;

const server = app.listen(PORT, () => {
    console.log(`Server is listening on port http://${HOST}:${PORT}`);
});

process.on("SIGINT", () => {
    console.log("\nShutdown signal received...");

    prisma.$disconnect();
    server.close(error => {
        process.exit(error ? 1 : 0);
    });
});