import * as filters from "../filter";
import prisma, { MatchingAlgorithms } from "../../../generated/prisma";

const templateFilter: prisma.Filter = {
    id: 0,
    guild_id: "",
    name: "",
    value: "",
    matching_algorithm: MatchingAlgorithms.ALL,
    is_insensitive: false,
    is_whitelist: false,
    created_at: new Date(),
    updated_at: new Date()

};

describe("Match: ALL", () => {  });

describe("Match: ANY", () => { 
    const filter: prisma.Filter = {
        ...templateFilter,
        name: "Block American Politics",
        value: String.raw`trump biden democrat republican gop dnc kamala harris`,
        is_insensitive: true
    };

    const testCases: { input: string, expected: boolean }[] = [
{
            input: "Republicans float new tax breaks for tips, local taxes in Trump budget package",
            expected: true  // Contains 'republican' and 'trump'.
        },
        {
            input: "Biden’s Approval Rating Dips Amid Economic Concerns",
            expected: true  // Contains 'biden'.
        },
        {
            input: "GOP Governors Call for Tougher Border Security Measures",
            expected: true  // Contains 'gop'.
        },
        {
            input: "Biden Announces New Initiative to Tackle Climate Change",
            expected: true  // Contains 'biden'.
        },
        {
            input: "Biden Announces New Initiative to Tackle Climate Change",
            expected: true  // Contains 'biden'.
        },
        {
            input: "Joe Biden gives thoughts on Donald Trump, Vladimir Putin, Ukraine, and Kamala Harris in first interview since leaving office",
            expected: true  // Contains 'biden', 'trump', 'kamala' and 'harris'.
        },
        {
            input: "UK Prime Minister Keir Starmer hails limited US-UK trade deal, but 10% duties remain",
            expected: false
        },
        {
            input: "Scientists discover new species of fish in Pacific Ocean",
            expected: false
        },
        {
            input: "Federal Reserve signals cautious approach to interest rate cuts in 2025",
            expected: false
        }
    ];

    for (const { input, expected } of testCases) {
        test(`Test input: ${input}`, () => {
            const result = filters.any(filter, input);
            expect(result).toBe(expected);
        });
    }
});

describe("Match: LITERAL", () => {  });

describe("Match: REGEX", () => {
    const filter: prisma.Filter = {
        ...templateFilter,
        name: "Block American Politics",
        value: String.raw`\b(trump|biden|democrat|republican|gop|dnc|kamala|harris)\b`,
        is_insensitive: true
    };

    const testCases: { input: string, expected: boolean }[] = [
        {
            input: "Republicans float new tax breaks for tips, local taxes in Trump budget package",
            expected: true  // Contains 'republican' and 'trump'.
        },
        {
            input: "Biden’s Approval Rating Dips Amid Economic Concerns",
            expected: true  // Contains 'biden'.
        },
        {
            input: "GOP Governors Call for Tougher Border Security Measures",
            expected: true  // Contains 'gop'.
        },
        {
            input: "Biden Announces New Initiative to Tackle Climate Change",
            expected: true  // Contains 'biden'.
        },
        {
            input: "Biden Announces New Initiative to Tackle Climate Change",
            expected: true  // Contains 'biden'.
        },
        {
            input: "Joe Biden gives thoughts on Donald Trump, Vladimir Putin, Ukraine, and Kamala Harris in first interview since leaving office",
            expected: true  // Contains 'biden', 'trump', 'kamala' and 'harris'.
        },
        {
            input: "UK Prime Minister Keir Starmer hails limited US-UK trade deal, but 10% duties remain",
            expected: false
        },
        {
            input: "Scientists discover new species of fish in Pacific Ocean",
            expected: false
        },
        {
            input: "Federal Reserve signals cautious approach to interest rate cuts in 2025",
            expected: false
        }
    ];

    for (const { input, expected } of testCases) {
        test(`Test input: ${input}`, () => {
            const result = filters.regex(filter, input);
            expect(result).toBe(expected);
        });
    }
});

describe("Match: FUZZY", () => {  });
