import "preline";
import $ from "jquery";
import _ from "lodash";
import noUiSlider from "nouislider";
import "datatables.net";
import "dropzone/dist/dropzone-min.js";
import * as VanillaCalendarPro from "vanilla-calendar-pro";
import * as FloatingUIDOM from "@floating-ui/dom";

import { Channel } from "discord.js";
import prisma from "../../../../generated/prisma";

// Preline: requirements
window._ = _;
window.$ = $;
window.jQuery = $;
window.DataTable = $.fn.dataTable;
window.noUiSlider = noUiSlider;
window.VanillaCalendarPro = VanillaCalendarPro;
window.FloatingUIDOM = FloatingUIDOM

document.addEventListener("DOMContentLoaded", () => {
    window.HSStaticMethods.autoInit("all");

    setTimeout(() => {
        window.dispatchEvent(new Event("preline:ready"));
    }, 100);
});

// Preline: necessary for header events.
window.addEventListener("load", () => {
    const inputs = document.querySelectorAll('.dt-container thead input');

    inputs.forEach(input => {
        (input as HTMLInputElement).addEventListener("keydown", (event: KeyboardEvent) => {
            if ((event.metaKey || event.ctrlKey) && event.key === "a") {
                (event.target as HTMLInputElement).select();
            }
        });
    });
});

/**
 * Formats a given timestamp to one of two formats depending on its age.
 * @param timestamp 
 * @returns 'DD MMM, HH:mm' if younger than 1 year, else 'DD MMM YYYY'
 */
export const formatTimestamp = (timestamp: string | number) => {
    const date = new Date(
        typeof timestamp === "string"
        ? timestamp.replace(" ", "T")
        : timestamp
    );

    // Day and short month (example: 21 Oct)
    const result = `${date.getDate()} ${date.toLocaleString("en-GB", { month: "short" })}`

    const now = new Date();

    // Difference is less than a year:      'DD MMM, HH:mm'
    // Or, difference is more than a year:  'DD MMM YYYY'
    return now.getFullYear() === date.getFullYear()
        ? result + `, ${date.getHours().toString().padStart(2, "0")}:${date.getMinutes().toString().padStart(2, "0")}`
        : result + ` ${date.getFullYear()}`;
}

export const verifyChannels = (data: prisma.Channel[], channels: Channel[]) => {
    return data.some(item => {
        return channels.map(channel => channel.id).includes(item.channel_id);
    });
};

export function genHexString(len=6) {
    let output = '';
    for (let i = 0; i < len; ++i) {
        output += (Math.floor(Math.random() * 16)).toString(16);
    }
    return output;
}