import { Request, Response, Router } from "express";

import feedController from "@server/controllers/guild/feed.controller";
import filterController from "@server/controllers/guild/filter.controller";
import styleController from "@server/controllers/guild/style.controller";
import contentController from "@server/controllers/guild/content.controller";

import feedApiController from "@server/controllers/guild/api/feed.controller";
import filterApiController from "@server/controllers/guild/api/filter.controller";
import styleApiController from "@server/controllers/guild/api/style.controller";

const router = Router();

router.get("/:guildId", (request: Request, response: Response) => {
    const guildId = request.params.guildId;
    response.redirect(`/guild/${guildId}/feeds`);
    return;
});

// Web routes

router.get("/:guildId/feeds", feedController.get);
router.get("/:guildId/filters", filterController.get);
router.get("/:guildId/styles", styleController.get);
router.get("/:guildId/content", contentController.get);

// API routes

router.post("/:guildId/feeds/api/datatable", feedApiController.datatable);
router.get("/:guildId/feeds/api", feedApiController.get);
router.post("/:guildId/feeds/api", feedApiController.post);
router.patch("/:guildId/feeds/api", feedApiController.patch);
router.delete("/:guildId/feeds/api", feedApiController.del);

router.post("/:guildId/filters/api/datatable", filterApiController.datatable);
router.get("/:guildId/filters/api/select", filterApiController.select);
router.get("/:guildId/filters/api", filterApiController.get);
router.post("/:guildId/filters/api", filterApiController.post);
router.patch("/:guildId/filters/api", filterApiController.patch);
router.delete("/:guildId/filters/api", filterApiController.del);

router.post("/:guildId/styles/api/datatable", styleApiController.datatable);
router.get("/:guildId/styles/api/select", styleApiController.select);
router.get("/:guildId/styles/api", styleApiController.get);
router.post("/:guildId/styles/api", styleApiController.post);
router.patch("/:guildId/styles/api", styleApiController.patch);
router.delete("/:guildId/styles/api", styleApiController.del);

export default router;